# CBCL face images

CBCL face images data set:
* 19 x 19 Grayscale PGM format images,
* Training set: 2429 faces, 4548 nonfaces, 
* Test set: 472 faces, 23573 nonfaces.

Dataset is at: http://cbcl.mit.edu/cbcl/software-datasets/FaceData2.html. 

Directory structure should look like:

    datasets/
      CBCL_faces/
        README
        face/
          face00001.pgm
          [...]
          face02429.pgm
        non-face/
          [...]
      [...]
